@@ -167,6 +167,7 @@ class DataJointSession:
     def lims_path(self) -> Optional[pathlib.Path]:
         if self.lims_info and (path := self.lims_info["storage_directory"]):
             return pathlib.Path('/'+path)
+        return None
 
     @property
     def npexp_path(self) -> Optional[pathlib.Path]:
@@ -305,11 +306,11 @@ class DataJointSession:
         with fabric.Connection(f"{hpc_user}@hpc-login") as ssh:
 
             # copy up-to-date files to hpc
-            src_dir = pathlib.Path(__file__).parent
+            src_dir = pathlib.Path(__file__).parent / 'hpc'
             slurm_launcher = "slurm_launcher.py"
             upload_script = "upload_session.py"
             hpc_dir = "np_datajoint/"
-            for file in (*tuple(src_dir.rglob('*.py')),):
+            for file in (src_dir / slurm_launcher, src_dir / upload_script):
                 ssh.put(file, hpc_dir)
 
             # launch upload job via slurm
@@ -475,10 +476,10 @@ class DataJointSession:
                         Config=dj_axon.boto3.s3.transfer.TransferConfig(**config.BOTO3_CONFIG),
                     )
                 try:    
-                    utils.update_metrics_csv_with_missing_columns(probe_idx, sorted_paramset_idx)
+                    utils.update_metrics_csv_with_missing_columns(self.session_folder, probe_idx, sorted_paramset_idx)
                 except Exception as exc:
                     logging.exception(exc)
-                utils.copy_files_from_raw_to_sorted(probe_idx, sorted_paramset_idx, make_symlinks=True, original_ap_continuous_dat=True)
+                utils.copy_files_from_raw_to_sorted(self.session_folder, probe_idx, sorted_paramset_idx, make_symlinks=True, original_ap_continuous_dat=True)
         logging.info(
             f"Finished downloading sorted data for {self.session_folder}"
         )
@@ -529,11 +530,11 @@ class DataJointSession:
 
 class Probe:
     
-    def __init__(self, session:str|utils.DataJointSession, probe_letter:str, **kwargs):
-        if isinstance(session, utils.DataJointSession):
+    def __init__(self, session:str|DataJointSession, probe_letter:str, **kwargs):
+        if isinstance(session, DataJointSession):
             self.session = session
         else:
-            self.session = utils.DataJointSession(session)
+            self.session = DataJointSession(session)
         self.probe_letter = probe_letter
         
     @property
@@ -655,7 +656,7 @@ class ProbeDataJoint(Probe):
     
     def __init__(self, *args, **kwargs):
         if (
-            (paramset_idx := kwargs.pop('paramset_idx', utils.DEFAULT_KS_PARAMS_INDEX)) is not None
+            (paramset_idx := kwargs.pop('paramset_idx', config.DEFAULT_KS_PARAMS_INDEX)) is not None
             and str(paramset_idx).strip().isdigit()
         ):
             self.paramset_idx = int(paramset_idx)
